#!/bin/bash

function help()
{
	echo "Usage: link_isp.sh up|down"
}
function cpuname()
{
	if [ -f /proc/device-tree/compatible ]; then
		COMP=$(tr -d '\0' < /proc/device-tree/compatible)
	else
		COMP=$(cat /etc/chroot/compatible)
	fi
	case "${COMP}" in
	*rk3588*)
		echo rk3588
		;;
	*rk3566*|*rk3568*)
		echo rk356x
		;;
	*rk3399*)
		echo rk3399
		;;
	*)
		echo unknown
		;;	
	esac
}

function lib_path()
{
	case "$(uname -m)" in
	aarch64)
		LIB_PATH=/usr/lib/aarch64-linux-gnu/
		;;
	arm)
		LIB_PATH=/usr/lib/arm-linux-gnueabihf/
		;;
	*)
		LIB_PATH=none
		;;
	esac

	echo ${LIB_PATH}
}

function link_isp()
{
	if [ ! -L librkaiq.so ]; then
		ln -sf librkaiq-$(cpuname).so librkaiq.so
	fi
	if [ ! -L librkaiq.a ]; then
		ln -sf librkaiq-$(cpuname).a librkaiq.a
	fi
}

case $1 in
up)
	cd $(lib_path); link_isp; cd -
	;;
down)
	rm -rf $(lib_path)/librkaiq.so
	rm -rf $(lib_path)/librkaiq.a
	;;
*)
	help
	;;
esac

sync
exit 0
