#!/bin/bash

LINK_LIST="libgbm.so.1.0.0 libEGL.so.1.1.0 libGLESv1_CM.so.1.2.0 libGLESv2.so.2.1.0 libwayland-egl.so.1.0.0 libOpenCL.so.1.0.0"
MALI_VER=1.9.0
GLBAK=glbak.tar.gz

function help()
{
	echo "Usage: link_mali.sh up|down"
}

function lib_path()
{
	case "$(uname -m)" in
	aarch64)
		LIB_PATH=/usr/lib/aarch64-linux-gnu/
		;;
	arm)
		LIB_PATH=/usr/lib/arm-linux-gnueabihf/
		;;
	*)
		LIB_PATH=none
		;;
	esac

	echo ${LIB_PATH}
}

function lib_mali()
{
	if [ -f /proc/device-tree/compatible ]; then
		COMP=$(tr -d '\0' < /proc/device-tree/compatible)
	else
		COMP=$(cat /etc/chroot/compatible)
	fi

	case "${COMP}" in
	*rk3588*)
		LIB_MALI=libmali-valhall-g610-g6p0-wayland-gbm-vulkan.so
		;;
	*rk3568*)
		LIB_MALI=libmali-bifrost-g52-g2p0-wayland-gbm.so
		;;
	*rk3399*)
		LIB_MALI=libmali-midgard-t86x-r18p0-wayland-gbm.so
		;;
	*)
		LIB_MALI=none
		;;
	esac

	echo ${LIB_MALI}
}

function default_wayland()
{
	account_path=/var/lib/AccountsService/users
	case $1 in
	on)
		if [ -d ${accout_path} ]; then
			for user in $(ls /home)
			do
				if [ ! -f ${account_path}/${user} ]; then
					echo "[User]" | tee ${account_path}/${user}
					echo "Session=" | tee -a ${account_path}/${user}
					echo "XSession=ubuntu-wayland" | tee -a ${account_path}/${user}
					echo "Icon=/home/${user}/.face" | tee -a ${account_path}/${user}
					echo "SystemAccount=false" | tee -a ${account_path}/${user}
					echo  | tee -a ${account_path}/${user}
					echo "[InputSource0]" | tee -a ${account_path}/${user}
					echo "xkb=us" | tee -a ${account_path}/${user}
				fi
			done
		fi
		;;
	off)
		if [ -d ${accout_path} ]; then
			for user in $(ls /home)
			do
				rm -rf ${account_path}/${user}
			done
		fi
		;;
	*)
		;;
	esac
}

function link_up()
{
	path=$(lib_path)
	mali=$(lib_mali)
	cd ${path}
	if [ "$(readlink libmali.so.${MALI_VER})" != "${mali}" ]; then
		ln -sf ${mali} libmali.so.${MALI_VER}
		ln -sf libmali.so.${MALI_VER} libmali.so.1
		ln -sf libmali.so.${MALI_VER} libmali.so
	fi

	mkdir -p bak
	if [ -f ${GLBAK} ]; then
		tar zxvf ${GLBAK} -C bak
	fi
	for l in ${LINK_LIST}
	do
		if [ ! -L $l ]; then
			cp $l bak/
		fi
	done
	cd bak; tar zcvf ../${GLBAK} *; cd ..; rm -rf bak

	for l in ${LINK_LIST}
	do
		if [ -f $l ] && [ ! -L $l ]; then
			rm -rf $l
			ln -sf libmali.so.${MALI_VER} $l
		fi
	done
	
	default_wayland on
}

function link_down()
{
	path=$(lib_path)
	default_wayland off

	cd ${path}
	tar zxvf ${GLBAK}
	cd -
}

case $1 in
up)
	link_up
	;;
down)
	link_down
	;;
*)
	help
	;;
esac

sync
exit 0
