#!/bin/bash

function help()
{
	echo "Usage: link_isp.sh up|down"
}
function cpuname()
{
	if [ -f /proc/device-tree/compatible ]; then
		COMP=$(tr -d '\0' < /proc/device-tree/compatible)
	else
		COMP=$(cat /etc/chroot/compatible)
	fi
	case "${COMP}" in
	*rk3588*)
		echo rk3588
		;;
	*rk3566*|*rk3568*)
		echo rk356x
		;;
	*rk3399*)
		echo rk3399
		;;
	*)
		echo unknown
		;;	
	esac
}

function lib_path()
{
	case "$(uname -m)" in
	aarch64)
		LIB_PATH=/usr/lib/aarch64-linux-gnu/
		;;
	arm)
		LIB_PATH=/usr/lib/arm-linux-gnueabihf/
		;;
	*)
		LIB_PATH=none
		;;
	esac

	echo ${LIB_PATH}
}

function include_path()
{
	echo /usr/include
}

function link_lib()
{
	if [ ! -L librknnrt.so ]; then
		ln -sf ../librknnrt_$(cpuname).so librknnrt.so
		cd ..; ln -sf librknnrt_$(cpuname).so librknnrt.so; cd -
	fi
}
function link_include()
{
	if [ ! -L rknn_api.h ]; then
		ln -sf rknn_api_$(cpuname).h rknn_api.h
	fi
}

case $1 in
up)
	cd $(lib_path); link_lib; cd -
	cd $(include_path); link_include; cd -
	;;
down)
	rm -rf $(lib_path)/librknnrt.so
	rm -rf $(lib_path)/../librknnrt.so
	rm -rf $(include_path)/rknn_api.h
	;;
*)
	help
	;;
esac

sync
exit 0
